# GetOSM

[![PyPI version](https://badge.fury.io/py/getosm.svg)](https://badge.fury.io/py/getosm)

GetOSM is an OpenStreetMap downloader written in Python that is agnostic of
GUI frameworks. It is used with
[tkinter](https://docs.python.org/3/library/tkinter.html) by
[ProjPicker](https://github.com/HuidaeCho/projpicker).

## Requirements

GetOSM uses the following standard modules:
* [sys](https://docs.python.org/3/library/sys.html)
* [math](https://docs.python.org/3/library/math.html)
* [urllib.request](https://docs.python.org/3/library/urllib.request.html)

## Demo GUIs

### osmtk: tkinter demo

![image](https://user-images.githubusercontent.com/7456117/126282231-34260f42-316d-4da9-9f0a-b95832f48d85.png)

### osmwx: wxPython demo

Only map viewing is implemented.

## License

Copyright (C) 2021 [Huidae Cho](https://idea.isnew.info/)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <<https://www.gnu.org/licenses/>>.
